@@ -175,13 +175,13 @@ impl WrapEvtSender {
         from_agent: AgentPubKey,
         zome_name: ZomeName,
         fn_name: FunctionName,
-        cap: Option<CapSecret>,
+        cap_secret: Option<CapSecret>,
         payload: ExternIO,
     ) -> impl Future<Output = HolochainP2pResult<SerializedBytes>> + 'static + Send {
         timing_trace!(
             {
                 self.0.call_remote(
-                    dna_hash, to_agent, from_agent, zome_name, fn_name, cap, payload,
+                    dna_hash, to_agent, from_agent, zome_name, fn_name, cap_secret, payload,
                 )
             },
             "(hp2p:handle) call_remote",
@@ -394,7 +394,7 @@ impl HolochainP2pActor {
         from_agent: AgentPubKey,
         zome_name: ZomeName,
         fn_name: FunctionName,
-        cap: Option<CapSecret>,
+        cap_secret: Option<CapSecret>,
         data: Vec<u8>,
     ) -> kitsune_p2p::actor::KitsuneP2pHandlerResult<Vec<u8>> {
         let evt_sender = self.evt_sender.clone();
@@ -406,7 +406,7 @@ impl HolochainP2pActor {
                     from_agent,
                     zome_name,
                     fn_name,
-                    cap,
+                    cap_secret,
                     ExternIO::from(data),
                 )
                 .await;
@@ -765,10 +765,10 @@ impl kitsune_p2p::event::KitsuneP2pEventHandler for HolochainP2pActor {
             crate::wire::WireMessage::CallRemote {
                 zome_name,
                 fn_name,
-                cap,
+                cap_secret,
                 data,
             } => self.handle_incoming_call_remote(
-                space, to_agent, from_agent, zome_name, fn_name, cap, data,
+                space, to_agent, from_agent, zome_name, fn_name, cap_secret, data,
             ),
             crate::wire::WireMessage::Get { dht_hash, options } => {
                 self.handle_incoming_get(space, to_agent, dht_hash, options)
@@ -814,19 +814,19 @@ impl kitsune_p2p::event::KitsuneP2pEventHandler for HolochainP2pActor {
         &mut self,
         space: Arc<kitsune_p2p::KitsuneSpace>,
         to_agent: Arc<kitsune_p2p::KitsuneAgent>,
-        _from_agent: Arc<kitsune_p2p::KitsuneAgent>,
+        from_agent: Arc<kitsune_p2p::KitsuneAgent>,
         payload: Vec<u8>,
     ) -> kitsune_p2p::event::KitsuneP2pEventHandlerResult<()> {
         let space = DnaHash::from_kitsune(&space);
         let to_agent = AgentPubKey::from_kitsune(&to_agent);
+        let from_agent = AgentPubKey::from_kitsune(&from_agent);
 
         let request =
             crate::wire::WireMessage::decode(payload.as_ref()).map_err(HolochainP2pError::from)?;
 
         match request {
             // error on these call type messages
-            crate::wire::WireMessage::CallRemote { .. }
-            | crate::wire::WireMessage::Get { .. }
+            crate::wire::WireMessage::Get { .. }
             | crate::wire::WireMessage::GetMeta { .. }
             | crate::wire::WireMessage::GetLinks { .. }
             | crate::wire::WireMessage::GetAgentActivity { .. }
@@ -837,6 +837,22 @@ impl kitsune_p2p::event::KitsuneP2pEventHandler for HolochainP2pActor {
                 )
                 .into())
             }
+            crate::wire::WireMessage::CallRemote {
+                zome_name,
+                fn_name,
+                cap_secret,
+                data,
+            } => {
+                let fut = self.handle_incoming_call_remote(
+                    space, to_agent, from_agent, zome_name, fn_name, cap_secret, data,
+                );
+                Ok(async move {
+                    let _ = fut?.await?;
+                    Ok(())
+                }
+                .boxed()
+                .into())
+            }
             crate::wire::WireMessage::Publish {
                 request_validation_receipt,
                 countersigning_session,
@@ -1010,15 +1026,15 @@ impl HolochainP2pHandler for HolochainP2pActor {
         to_agent: AgentPubKey,
         zome_name: ZomeName,
         fn_name: FunctionName,
-        cap: Option<CapSecret>,
+        cap_secret: Option<CapSecret>,
         payload: ExternIO,
     ) -> HolochainP2pHandlerResult<SerializedBytes> {
         let space = dna_hash.into_kitsune();
         let to_agent = to_agent.into_kitsune();
         let from_agent = from_agent.into_kitsune();
 
-        let req =
-            crate::wire::WireMessage::call_remote(zome_name, fn_name, cap, payload).encode()?;
+        let req = crate::wire::WireMessage::call_remote(zome_name, fn_name, cap_secret, payload)
+            .encode()?;
 
         let kitsune_p2p = self.kitsune_p2p.clone();
         Ok(async move {
@@ -1031,6 +1047,40 @@ impl HolochainP2pHandler for HolochainP2pActor {
         .into())
     }
 
+    #[tracing::instrument(skip(self), level = "trace")]
+    fn handle_remote_signal(
+        &mut self,
+        dna_hash: DnaHash,
+        from_agent: AgentPubKey,
+        to_agent_list: Vec<AgentPubKey>,
+        zome_name: ZomeName,
+        fn_name: FunctionName,
+        cap: Option<CapSecret>,
+        payload: ExternIO,
+    ) -> HolochainP2pHandlerResult<()> {
+        let space = dna_hash.into_kitsune();
+        let to_agent_list = to_agent_list
+            .into_iter()
+            .map(|a| a.into_kitsune())
+            .collect();
+        let from_agent = from_agent.into_kitsune();
+
+        let req =
+            crate::wire::WireMessage::call_remote(zome_name, fn_name, cap, payload).encode()?;
+
+        let timeout = self.tuning_params.implicit_timeout();
+
+        let kitsune_p2p = self.kitsune_p2p.clone();
+        Ok(async move {
+            kitsune_p2p
+                .targeted_broadcast(space, from_agent, to_agent_list, timeout, req, true)
+                .await?;
+            Ok(())
+        }
+        .boxed()
+        .into())
+    }
+
     #[tracing::instrument(skip(self), level = "trace")]
     fn handle_publish(
         &mut self,
@@ -1320,6 +1370,7 @@ impl HolochainP2pHandler for HolochainP2pActor {
                 .into(),
         )
     }
+
     #[tracing::instrument(skip(self), level = "trace")]
     fn handle_countersigning_authority_response(
         &mut self,
@@ -1340,7 +1391,7 @@ impl HolochainP2pHandler for HolochainP2pActor {
         let kitsune_p2p = self.kitsune_p2p.clone();
         Ok(async move {
             kitsune_p2p
-                .targeted_broadcast(space, from_agent, agents, timeout, payload)
+                .targeted_broadcast(space, from_agent, agents, timeout, payload, false)
                 .await?;
             Ok(())
         }
